@@ -53,6 +53,7 @@ namespace Phonon
 QMutex probeMutex;
 static PulseSupport *s_instance = NULL;
 static bool s_wasShutDown = false;
+static bool s_pulseActive = false;
 
 #ifdef HAVE_PULSEAUDIO
 /***
@@ -143,8 +144,6 @@ class PulseUserData
         QMap<Phonon::CaptureCategory, QMap<int, int> > newCaptureDevicePriorities; // prio, device
 };
 
-static bool s_pulseActive = false;
-
 static pa_glib_mainloop *s_mainloop = NULL;
 static pa_context *s_context = NULL;
 
@@ -438,11 +437,12 @@ static void ext_device_manager_read_cb(pa_context *c, const pa_ext_device_manage
         // our device info and can exit and reconnect
         if (s_context != c)
             pa_context_disconnect(c);
+
+        return; // eol
     }
 
-    if (!info)
-        return;
-
+    // If we aren't at eol we expect info to be valid!
+    Q_ASSERT(info);
     Q_ASSERT(info->name);
     Q_ASSERT(info->description);
     Q_ASSERT(info->icon);
@@ -820,7 +820,9 @@ void PulseSupport::debug()
 }
 
 PulseSupport::PulseSupport()
- : QObject(), mEnabled(false)
+    : QObject()
+    , mEnabled(false)
+    , m_requested(false)
 {
 #ifdef HAVE_PULSEAUDIO
 
@@ -838,7 +840,8 @@ PulseSupport::PulseSupport()
     }
 
     // We require a glib event loop
-    if (!QByteArray(QAbstractEventDispatcher::instance()->metaObject()->className()).contains("EventDispatcherGlib")) {
+    if (!QByteArray(QAbstractEventDispatcher::instance()->metaObject()->className()).contains("EventDispatcherGlib") &&
+        !QByteArray(QAbstractEventDispatcher::instance()->metaObject()->className()).contains("GlibEventDispatcher")) {
         qWarning("WARNING: Disabling PulseAudio integration for lack of GLib event loop.");
         return;
     }
@@ -928,15 +931,36 @@ void PulseSupport::connectToDaemon()
 bool PulseSupport::isActive()
 {
 #ifdef HAVE_PULSEAUDIO
-    return mEnabled && s_pulseActive;
+    return mEnabled && isUsed();
 #else
     return false;
 #endif
 }
 
+bool PulseSupport::isUsed()
+{
+   return isRequested() && isUsable();
+}
+
+bool PulseSupport::isUsable() const
+{
+    return s_pulseActive;
+}
+
+bool PulseSupport::isRequested() const
+{
+    return m_requested;
+}
+
+void PulseSupport::request(bool requested)
+{
+    m_requested = requested;
+}
+
 void PulseSupport::enable(bool enabled)
 {
     mEnabled = enabled;
+    request(enabled); // compat, enable needs to imply request.
 #ifdef HAVE_PULSEAUDIO
     logMessage(QString::fromLocal8Bit("Enabled Breakdown: mEnabled: %1, s_pulseActive %2").arg(mEnabled ? "Yes" : "No" ).arg(s_pulseActive ? "Yes" : "No"));
 #endif
@@ -1271,7 +1295,7 @@ void PulseSupport::setupStreamEnvironment(QString streamUuid)
 
 void PulseSupport::emitObjectDescriptionChanged(ObjectDescriptionType type)
 {
-    if (mEnabled)
+    if (isUsed())
         emit objectDescriptionChanged(type);
 }
 
